# PollingApp 

[![Run tests with Tox](https://github.com/unipoll/API/actions/workflows/tests.yaml/badge.svg)](https://github.com/unipoll/API/actions/workflows/tests.yaml)
[![Coverage Status](https://coveralls.io/repos/github/unipoll/API/badge.svg?branch=main)](https://coveralls.io/github/unipoll/API?branch=main)
[![Version Badge](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fapi.github.com%2Frepos%2Funipoll%2FAPI%2Freleases%2Flatest&query=%24.name&label=Release%20version&color=violet)](https://github.com/unipoll/API/releases)
[![Docker Image](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fregistry.hub.docker.com%2Fv2%2Frepositories%2Funipoll%2Fapi%2Ftags%2F&query=%24.results.1.name&logo=docker&label=Docker%20image)](https://hub.docker.com/repository/docker/unipoll/api/tags)

**This is the Development Branch**

### Useful Links:

- [Developer Wiki](https://github.com/mike-pisman/PollingAPI/wiki) 

- [Polling API](https://polling.website/)

- [Polling API Swagger Docs](https://polling.website/docs)

- [Polling API Swagger ReDoc](https://polling.website/redoc)

- [Postman Documentation v0.0.5](https://documenter.getpostman.com/view/19614303/2s8Z6vZEBr)

- [Postman Documentation v0.0.4](https://documenter.getpostman.com/view/19614303/2s8Z6sbvxz)
